@@ -1,7 +1,7 @@
 var interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspector =
 [
-    [ "XController", "interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspector.html#ad5df911dd9c36ae6ea3153a3f2d3381c", null ],
-    [ "XDispatchProvider", "interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspector.html#ac5b564613a27c4bfa337a5d265bdf93a", null ],
+    [ "com::sun::star::frame::XController", "interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspector.html#ad5df911dd9c36ae6ea3153a3f2d3381c", null ],
+    [ "com::sun::star::frame::XDispatchProvider", "interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspector.html#ac5b564613a27c4bfa337a5d265bdf93a", null ],
     [ "inspect", "interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspector.html#af91025466c181f5dc6d09cfee58b74ec", null ],
     [ "InspectorModel", "interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspector.html#aab507adb434f393d16fee4bfbad0173f", null ],
     [ "InspectorUI", "interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspector.html#a3194577ce3e0b75040fbd3a29fdf3e62", null ]
