@@ -1,7 +1,7 @@
 var interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotation =
 [
-    [ "XPropertySet", "interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotation.html#a3564ba008f9f7317d1ed8ef8349269fb", null ],
-    [ "XComponent", "interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotation.html#affe8ef6c7d1653b20260774276d31511", null ],
+    [ "::com::sun::star::beans::XPropertySet", "interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotation.html#a3564ba008f9f7317d1ed8ef8349269fb", null ],
+    [ "::com::sun::star::lang::XComponent", "interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotation.html#affe8ef6c7d1653b20260774276d31511", null ],
     [ "Anchor", "interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotation.html#a9954a67104683c2900597653d50c363a", null ],
     [ "Author", "interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotation.html#a13cf46aff4dea87a8f5285a09efece69", null ],
     [ "DateTime", "interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotation.html#adbcb6afc37761b99eef1099e350b2140", null ],
