@@ -1,6 +1,6 @@
 var servicecom_1_1sun_1_1star_1_1sdbcx_1_1Group =
 [
-    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Group.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
+    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Group.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
     [ "XAuthorizable", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Group.html#a0dad432bef89bd4887e2b2de78db1c73", null ],
     [ "XUsersSupplier", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Group.html#a9921be51947ea039bc5234f50899ccb2", null ],
     [ "Name", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Group.html#a7ee9065718e6628dc7791b756fa6c0f9", null ]
