@@ -1,8 +1,8 @@
 var servicecom_1_1sun_1_1star_1_1table_1_1TableColumn =
 [
-    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1table_1_1TableColumn.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
-    [ "XNamed", "servicecom_1_1sun_1_1star_1_1table_1_1TableColumn.html#a06d9bde12d6408506b7a64e0e0d1408a", null ],
-    [ "XCellRange", "servicecom_1_1sun_1_1star_1_1table_1_1TableColumn.html#a695b26055647481e5442ec825165158b", null ],
+    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1table_1_1TableColumn.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
+    [ "com::sun::star::container::XNamed", "servicecom_1_1sun_1_1star_1_1table_1_1TableColumn.html#a06d9bde12d6408506b7a64e0e0d1408a", null ],
+    [ "com::sun::star::table::XCellRange", "servicecom_1_1sun_1_1star_1_1table_1_1TableColumn.html#a695b26055647481e5442ec825165158b", null ],
     [ "IsStartOfNewPage", "servicecom_1_1sun_1_1star_1_1table_1_1TableColumn.html#a05723b3f409c70881a51a152a581e8ab", null ],
     [ "IsVisible", "servicecom_1_1sun_1_1star_1_1table_1_1TableColumn.html#a9a886e02e55d4f1dbabbb84da0ae7e7f", null ],
     [ "OptimalWidth", "servicecom_1_1sun_1_1star_1_1table_1_1TableColumn.html#a0ca7f53ef79d5b48cc6c539f76c0a13f", null ],
