@@ -1,6 +1,6 @@
 var servicecom_1_1sun_1_1star_1_1ucb_1_1CachedContentResultSet =
 [
-    [ "ContentResultSet", "servicecom_1_1sun_1_1star_1_1ucb_1_1CachedContentResultSet.html#abd70b5c9f91f0435c555f222de07f72c", null ],
+    [ "com::sun::star::ucb::ContentResultSet", "servicecom_1_1sun_1_1star_1_1ucb_1_1CachedContentResultSet.html#abd70b5c9f91f0435c555f222de07f72c", null ],
     [ "FetchDirection", "servicecom_1_1sun_1_1star_1_1ucb_1_1CachedContentResultSet.html#a5f21e7b675501abba335f05029ca9698", null ],
     [ "FetchSize", "servicecom_1_1sun_1_1star_1_1ucb_1_1CachedContentResultSet.html#a50859cae047f6fad1388342516c909a2", null ]
 ];
\ No newline at end of file
